function [LdB,delta,E]=LambdaDB(E,m,Ep)
% LambdaDB calcula la longitud de onda de De Broglie de un objeto fsico 
%  utilizando su energa, su masa, y los varios valores de la energa potencial 
%  Ep(i) (i=1,2,...). 
%  Tambin LambdaDB calcula la profundidad de penetracin (delta) en una regin 
%  donde la energa potencial es ms grande que la del objeto fsico.
% 
%   [LdB,delta,E]=LambdaDB(E,m,Ep)
%       >> E        = Energa del objeto fsico (eV)
%       >> m        = Masa del objeto fsico (respecto a la del electrn)
%       >> Ep       = Energa potencial Ep(i) (eV)
%       << LdB      = Longitud de onda de De Broglie LdB(i) (nm)
%       << delta    = Profundidad de penetracin delta(i) (nm)
%	  << E
%                           
%   Olivier Pujol (2010)
%    
%% Verificaciones

if (m<=0), error('La masa tiene que ser positiva!');end

% Se tiene verificar que todos los valores de E  son diferentes de cualquier valor de Ep
for i=1:length(Ep)
    Ind=(abs(E-Ep(i))<eps); % Buscando valores de E tal que E=Ep
    E=E(Ind~=1);            % Los valores anteriores no se guardan
end

clear i Ind

%% Clculo de LDB y Delta

LdB=cell(size(E));
delta=cell(size(E));
k=cell(size(E));
%
for n=1:length(E)
    k{n}=VectOnda(E(n),m,Ep);
        
    Ind=nan(1,length(k{n}));
    
    for ik=1:length(k{n}) 
        Ind(ik)=isreal(k{n}(ik));
    end

    LdB{n}=nan(1,length(k{n}));
    LdB{n}(Ind==1)=2*pi./(k{n}(Ind==1));
    delta{n}=nan(1,length(k{n}));
    delta{n}(Ind==0)=1./(2*imag(k{n}(Ind==0)));
    
end
%
if (length(E)==1)
    LdB=LdB{1};
    delta=delta{1};
end

return;