function [M,xt,Ep]=digitalización(x,Epc)
% DIGITALIZATION transforma una energía potencial continua en una energía 
%   potencial digitalizada, es decir formada por varios escalones.
%
%   [M,xt,Ep]=DIGITALIZATION(x,Epc)
%       >> x    = Coordenada en el eje Ox
%       >> Epc  = Energía potencial continua 
%       << M    = Escalones de energía potencial
%       << xt   = Posición de los escalones 
%       << Ep   = Energía potencial digitalizada
%
%   Olivier Pujol (2010)
%
%% Escalones constituyendo la energía potencial digitalizada

M=cell(1,(length(x)-1));
for n=1:length(x)-1
    M{n}=['M',num2str(n)];
end
%
%% Digitalización

[xs,Eps]=stairs(x,Epc);    

% Posición de los escalones M

xs=xs-0.5*(x(2)-x(1));      % xs es trasladado de la mitad del incremento en Ox
xt=xs(2.*(1:length(x)-1));  % Selección de un valor sobre dos desde xs(2)

% Altura del escalón M

Ep=Eps(2.*(1:length(x)-1)); % Igual para Eps en aras de recoger la altura del escalón M

% Se tiene que imponer el valor de la energía potencial de salida. 
% Se fija en el último valor de Epc 

Ep(length(x))=Epc(end);

%% Gráfico

figure
plot(xs,Eps,'r',x,Epc,'b');
axis tight;
grid on;
box on;
set(gca,'Xminortick','on','Yminortick','on');
xlabel('x (nm)');
ylabel('Energía (eV)');
title('Energía potencial');
%
return;