function sisconf(sys,E)
% SISCONF determina las energías de los estados ligados de un objeto físico
%  confinado en un pozo de energía potencial. 
%  También se ofrece una representación gráfica del pozo y de esas energías.
%
%	SISCONF(sys,E)
%		>> sys 		= Sistema
%		>> E		= Energía del objeto físico
%
%	Olivier Pujol (2010)
%

if (nargin~=2);error('¡Número de argumentos de entrada incorrecto!');end
if (isa(sys,'cell')==0),error('¡El primer argumento tiene que ser de tipo ''cell''!');end

%% Cálculo de la matriz de transferencia abcd del pozo

TES=matriz(sys);

%% Extracción del elemento d

d=nan(1,length(TES));   % Inicialización

for iT=1:size(TES,2)
    d(iT)=TES{iT}(2,2);   % Elemento d
end

clear TES

%% Gráfico

%   Dibujo del pozo
L=get(sys{1}{length(sys{1})},'Posición')-get(sys{1}{2},'Posición'); % Anchura del pozo
xmin=get(sys{1}{2},'Posición')-0.5*L;                       % Valor mínimo de x 
xmax=get(sys{1}{length(sys{1})},'Posición')+0.5*L;          % Valor máximo de x 

pos=nan(1,length(sys{1})-1);    % Inicialización de la posición del escalón
Ep=nan(1,length(sys{1})-1);     % Inicialización de la altura del escalón
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'escalón')==0),error('¡Tipo de argumento incorrecto!');end
    pos(i-1)=get(sys{1}{i},'Posición');
    Ep(i-1)=get(sys{1}{i},'EnergíaPotencialSalida');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];

figure
subplot(1,2,1)
hs=stairs(pos,Ep);              % Dibujo del pozo 
set(hs,'LineWidth',2,'Color','b');
if (min(Ep)<0),axis([xmin xmax min(Ep) max(E)+0.1*abs(min(Ep))]);end
if (min(Ep)>=0),axis([xmin xmax min(Ep) max(E)+0.1*max(E)]);end
set(gca,'xminortick','on','yminortick','on');
grid on;
box on;
xlabel('{\itx} (nm)');
ylabel('Energía (eV)');
title('{Pozo de energía potencial}');

%   La energía de un estado ligado (confinado) corresponde teóricamente a d=0.
%   Numéricamente, sólo el mínimo de d se considera ya que el número finito  
%   de valores de E y las aproximaciones numéricas impiden obtener rigorosamente d = 0.  
%   Asimismo, para mostrar mejor esos mínima, es ventajoso considerar 
%   el logaritmo decimal del valor absoluto de d. 
subplot(1,2,2);
plot(log(abs(d)),E,'b');
if (min(Ep)<0),axis([min(log(abs(d))) max(log(abs(d))) min(Ep) max(E)+0.1*abs(min(Ep))]);end
if (min(Ep)>=0),axis([min(log(abs(d))) max(log(abs(d))) min(Ep) max(E)+0.1*max(E)]);end
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
title('Energía de los estados ligados (o confinados)');
xlabel('ln(|d|)');
ylabel('Energía (eV)','Color','k');

return;
